summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/private/kopetecommand.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/private/kopetecommand.h')
-rw-r--r--kopete/libkopete/private/kopetecommand.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/libkopete/private/kopetecommand.h b/kopete/libkopete/private/kopetecommand.h
index d49de208..47286967 100644
--- a/kopete/libkopete/private/kopetecommand.h
+++ b/kopete/libkopete/private/kopetecommand.h
@@ -36,7 +36,7 @@ class Command : public KAction
/**
* Creates a Kopete::Command object
*
* @param tqparent The plugin who owns this command
* @param command The command we want to handle, not including the '/'
* @param handlerSlot The slot used to handle the command. This slot must
* accept two parameters, a TQString of arguments, and a Kopete::ChatSession
@@ -50,7 +50,7 @@ class Command : public KAction
* @param cut The shortcut for the command
* @param pix The icon to use for the command
*/
- Command( TQObject *tqparent, const TQString &command, const char* handlerSlot,
+ Command( TQObject *parent, const TQString &command, const char* handlerSlot,
const TQString &help = TQString(), CommandHandler::CommandType type = CommandHandler::Normal, const TQString &formatString = TQString(),
uint minArgs = 0, int maxArgs = -1, const KShortcut &cut = 0,
const TQString &pix = TQString() );
@@ -36,7 +36,7 @@ class Command : public KAction
* Creates a Kopete::Command object
*
- * @param tqparent The plugin who owns this command
+ * @param parent The plugin who owns this command
* @param command The command we want to handle, not including the '/'
* @param handlerSlot The slot used to handle the command. This slot must